@@ -14,7 +14,7 @@ from teedoc import Fake_Logger
 import tempfile
 import time
 
-__version__ = "2.10.3"
+__version__ = "2.10.4"
 
 class Plugin(Plugin_Base):
     name = "teedoc-plugin-markdown-parser"
@@ -64,9 +64,9 @@ class Plugin(Plugin_Base):
         self.logger.i("-- plugin <{}> config: {}".format(self.name, self.config))
         if not self.multiprocess:
             from .renderer import create_markdown_parser
-            from .parse_metadata import Meta_Parser
+            from teedoc.metadata_parser import Metadata_Parser
             self.create_markdown_parser = create_markdown_parser 
-            self.Meta_Parser = Meta_Parser
+            self.Meta_Parser = Metadata_Parser
         self.assets_abs_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "assets")
         self.files_to_copy = {}
         if self.config["mermaid"]:
@@ -78,9 +78,9 @@ class Plugin(Plugin_Base):
             every time create a new process, this func will be invoke
         '''
         from .renderer import create_markdown_parser
-        from .parse_metadata import Meta_Parser
+        from teedoc.metadata_parser import Metadata_Parser
         self.md_parser = create_markdown_parser()
-        self.meta_parser = Meta_Parser()
+        self.meta_parser = Metadata_Parser()
 
 
     def on_new_process_del(self):
@@ -118,46 +118,20 @@ class Plugin(Plugin_Base):
                         else:
                             md_parser = self.md_parser
                             meta_parser = self.meta_parser
-                        metadata, content_no_meta = meta_parser.parse_meta(content)
+                        metadata, content_no_meta = meta_parser.parse_meta(content, file)
                         html = md_parser(content_no_meta)
                     except Exception as e:
                         self.logger.w("parse markdown file {} fail, please check markdown content format".format(file))
                         raise e
-                    title = metadata.get("title", "")
-                    desc = metadata.get("desc", "")
-                    author = metadata.get("author", "")
-                    keywords = []
-                    if "keywords" in metadata:
-                        if type(metadata["keywords"]) == list:
-                            keywords = metadata["keywords"]
-                        elif type(metadata["keywords"]) == str:
-                            keywords = metadata["keywords"].split(",")
-                    tags = []
-                    if "tags" in metadata:
-                        if type(metadata["tags"]) == list:
-                            tags = metadata["tags"]
-                        elif type(metadata["tags"]) == str:
-                            tags = metadata["tags"].split(",")
-                    date = None
-                    ts = None
-                    if "date" in metadata and (type(metadata["date"]) == datetime.datetime or type(metadata["date"]) == datetime.date):
-                        date = metadata["date"]
-                        if type(date) == datetime.date:
-                            ts = int(time.mktime(date.timetuple()))
-                        else:
-                            ts = int(date.timestamp())
-                    else:
-                        date = metadata.get("date")
-                        ts = int(os.stat(file).st_mtime)
                     result["htmls"][file] = {
-                        "title": title,
-                        "desc": desc,
-                        "keywords": keywords,
-                        "tags": tags,
+                        "title": metadata["title"],
+                        "desc": metadata["desc"],
+                        "keywords": metadata["keywords"],
+                        "tags": metadata["tags"],
                         "body": html,
-                        "date": date,
-                        "ts": ts,
-                        "author": author,
+                        "date": metadata["date"],
+                        "ts": metadata["ts"],
+                        "author": metadata["author"],
                         # "toc": html.toc_html if html.toc_html else "",
                         "toc": "", # just empty, toc generated by js but not python
                         "metadata": metadata,
